#!/usr/bin/env node
import fs from 'fs';
import path from 'path';
import inquirer from 'inquirer';
import handlebars from 'handlebars';
import { rmdirOrfile } from "./del";
import { Command } from 'commander';
import gitclone from 'git-clone/promise';
import { initPrompts, gitPath } from './config';


const program = new Command();
const { version } = require('../package.json');

program
    .name('npm-init-cli')
    .description('game npm库初始化脚手架')
    .version(version);

program
    .command('init <name>')
    .description('init game project')
    .action(async (name: string) => {
        const { isServer } = await inquirer.prompt(initPrompts as any);
        const clonePath = path.join(process.cwd(), '');
        await rmdirOrfile(clonePath);
        await gitclone(gitPath, clonePath, {
            checkout: !isServer ? 'client_template' : 'server_template'
        });
        rmdirOrfile(path.join(clonePath, '.git'));
        const packagePath = path.join(clonePath, 'package.json');
        if (fs.existsSync(packagePath)) {
            const content = fs.readFileSync(packagePath).toString();
            const template = handlebars.compile(content);
            const result = template({ name });
            fs.writeFileSync(packagePath, result);
            console.log('modify package.json complate');
        } else {
            throw new Error('no package.json');
        }
    })

program.parse();
